# Automatic Running

When it comes time to distribute your game, you can package up the interpreter with your game into an archive or installer. But if you want the user to be able to start your game just by clicking on an icon, you can rename Git.exe to the same as the name as your game's Glulx file (apart from the .exe file extension). When the interpreter starts up it first looks for a Blorb file with the same name as the executable, and if one is found, loads and runs it straight away. So, if your game file is Foo.blb and the renamed interpreter executable is Foo.exe, all the user needs to do to run your game is double click on Foo.exe.